@@ -38,6 +38,10 @@ shinyServer(function(input, output, session) {
   
   source("server/consoleServer.R", local = TRUE)
   
+  if (is2910) {
+    shinyjs::enable("twitter_semantic_assoc") 
+  }
+  
   # reset collect consoles on startup
   observeEvent(input$sidebar_menu, {
     resetConsole("twitter_console", FALSE)
@@ -45,10 +49,6 @@ shinyServer(function(input, output, session) {
     resetConsole("reddit_console", FALSE)
   }, once = TRUE, ignoreInit = FALSE)
   
-  if (!v029) {
-    js$disableTab("'Create Network'")  
-  }
-  
   # stop app when browser closes
   session$onSessionEnded(function() {
     if (isLocal) {
