@@ -3,7 +3,7 @@
 #' Collects Reddit thread comments and creates an actor network using the vosonSML package.
 #'
 
-#### values ----------------------------------------------------------------------------------------------------------- #
+#### values ---------------------------------------------------------------------------------------------------------- #
 
 red_rv <- reactiveValues(
   reddit_data = NULL,      # dataframe returned by vosonSML collection
@@ -16,7 +16,7 @@ red_rv <- reactiveValues(
 
 reddit_url_list <- c()   # list of reddit threads to collect on
 
-#### events ----------------------------------------------------------------------------------------------------------- #
+#### events ---------------------------------------------------------------------------------------------------------- #
 
 # when the reddit add thread url button is pushed update the list and input fields
 observeEvent(input$reddit_add_url_button, {
@@ -45,40 +45,20 @@ observeEvent(input$reddit_collect_button, {
   withProgress(message = 'Collecting threads', value = 0.5, {
     
     withConsoleRedirect("reddit_console", {
-      # withCallingHandlers({
-      # shinyjs::html(id = "reddit_console", html = "")
-      
       url_list <- sapply(reddit_url_list, function(x) paste0("https://reddit.com/", x))
       
       # collect reddit data and print any output to console
       tryCatch({
-        red_rv$reddit_data <<- collectRedditData(url_list)
-        red_rv$data_cols <<- names(red_rv$reddit_data)
+        red_rv$reddit_data <- collectRedditData(url_list)
+        red_rv$data_cols <- names(red_rv$reddit_data)
       }, error = function(err) {
         incProgress(1, detail = "Error")
         cat(paste('reddit collection error:', err))
         return(NULL)
       })
       
-      if (!v029) {
-        incProgress(0.5, detail = "Creating network")
-        
-        # if reddit data collected create igraph graph object
-        if (!is.null(red_rv$reddit_data)) {
-          tryCatch({
-            netList <- createRedditActorNetwork(red_rv$reddit_data)
-            red_rv$reddit_graphml <<- netList$network
-            red_rv$reddit_wt_graphml <<- netList$networkWT
-          }, error = function(err) {
-            incProgress(1, detail = "Error")
-            cat(paste('reddit graphml error:', err))
-            return(NULL)
-          })
-        }
-      }
-      
       incProgress(1, detail = "Finished")
-      
+      updateTabItems(session, "reddit_control_tabset", selected = "Create Network")
     }) # withConsoleRedirect
     
   }) # withProgress
@@ -106,28 +86,24 @@ observeEvent(input$reddit_create_button, {
   
   withProgress(message = 'Creating network', value = 0.5, {
     
-  withConsoleRedirect("reddit_console", {
-    if (net_type == "activity") {
-      network <- vosonSML::Create(isolate(red_rv$reddit_data), "activity", verbose = TRUE)
-      if (add_text) { network <- vosonSML::AddText(network, isolate(red_rv$reddit_data)) }
-    } else if (net_type == "actor") {
-      network <- vosonSML::Create(isolate(red_rv$reddit_data), "actor", verbose = TRUE)
-      if (add_text) { network <- vosonSML::AddText(network, isolate(red_rv$reddit_data)) }
-    }
-    if (!is.null(network)) {
-      red_rv$reddit_network <- network
-      red_rv$reddit_graphml <- vosonSML::Graph(network) 
-    }
-  })
+    withConsoleRedirect("reddit_console", {
+      if (net_type == "activity") {
+        network <- vosonSML::Create(isolate(red_rv$reddit_data), "activity", verbose = TRUE)
+        if (add_text) { network <- vosonSML::AddText(network, isolate(red_rv$reddit_data)) }
+      } else if (net_type == "actor") {
+        network <- vosonSML::Create(isolate(red_rv$reddit_data), "actor", verbose = TRUE)
+        if (add_text) { network <- vosonSML::AddText(network, isolate(red_rv$reddit_data)) }
+      }
+      if (!is.null(network)) {
+        red_rv$reddit_network <- network
+        red_rv$reddit_graphml <- vosonSML::Graph(network) 
+      }
+    }) # withConsoleRedirect
   
-  incProgress(1, detail = "Finished")
-  })
+    incProgress(1, detail = "Finished")
+  }) # withProgress
   
   shinyjs::enable("reddit_create_button")
-  # shinyjs::runjs("jQuery( function() { var pre = jQuery('#reddit_console');
-  #                                      pre.scrollTop( pre.prop('scrollHeight')+200 ); }); ")
-  # 
-  # scrollIntoView()
   
   delay(gbl_scroll_delay, js$scroll_console("reddit_console"))
 })
@@ -137,18 +113,10 @@ callModule(collectDataButtons, "reddit", data = reactive({ red_rv$reddit_data })
 
 callModule(collectNetworkButtons, "reddit", network = reactive({ red_rv$reddit_network }), file_prefix = "reddit")
 
-if (v029) {
-  callModule(collectGraphButtons_, "reddit", graph_data = reactive({ red_rv$reddit_graphml }), file_prefix = "reddit")
-  
-  reddit_view_rvalues <- callModule(collectViewGraphButtons, "reddit", graph_data = reactive({ red_rv$reddit_graphml }))  
-} else {
-  callModule(collectGraphButtons, "reddit", graph_data = reactive({ red_rv$reddit_graphml }), 
-             graph_wt_data = reactive({ red_rv$reddit_wt_graphml }), file_prefix = "reddit")
-  
-  reddit_view_rvalues <- callModule(collectViewGraphButtons, "reddit", 
-                                     graph_data = reactive({ red_rv$reddit_graphml }), 
-                                     graph_wt_data = reactive({ red_rv$reddit_wt_graphml }))
-}
+
+callModule(collectGraphButtons_, "reddit", graph_data = reactive({ red_rv$reddit_graphml }), file_prefix = "reddit")
+
+reddit_view_rvalues <- callModule(collectViewGraphButtons, "reddit", graph_data = reactive({ red_rv$reddit_graphml }))
 
 observeEvent(reddit_view_rvalues$data, {
   setGraphView(data = isolate(reddit_view_rvalues$data), 
@@ -162,7 +130,7 @@ observeEvent(reddit_view_rvalues$data, {
 observeEvent(input$clear_reddit_console, {
   resetConsole("reddit_console")
 })
-#### output ----------------------------------------------------------------------------------------------------------- #
+#### output ---------------------------------------------------------------------------------------------------------- #
 
 # render reddit collection arguments
 output$reddit_arguments_output <- renderText({
@@ -170,8 +138,10 @@ output$reddit_arguments_output <- renderText({
   input$reddit_remove_url_button
   
   # do not update arguments text on input field or list changes
-  isolate({input$reddit_url_input
-    input$reddit_url_list_output})
+  isolate({
+    input$reddit_url_input
+    input$reddit_url_list_output
+  })
   
   # get reddit collection arguments output
   redditArgumentsOutput()
@@ -199,17 +169,15 @@ observeEvent(input$clear_all_reddit_dt_columns, {
 observeEvent(input$reset_reddit_dt_columns, {
   updateCheckboxGroupInput(session, "show_reddit_cols", label = NULL,
                            choices = isolate(red_rv$data_cols),
-                           selected = c("structure", "comm_date", "subreddit", "user", "comment_score", 
-                                        "comment", "thread_id"),
+                           selected = c("subreddit", "thread_id", "comm_id", "comm_date", "user", 
+                                        "comment_score", "comment"),
                            inline = TRUE)
 })
 
 output$reddit_data_cols_ui <- renderUI({
   data <- red_rv$data_cols
   
-  if (is.null(data)) {
-    return(NULL)
-  }
+  if (is.null(data)) { return(NULL) }
   
   conditionalPanel(condition = 'input.expand_show_reddit_cols',
                    div(actionButton("select_all_reddit_dt_columns", "Select all"), 
@@ -217,13 +185,13 @@ output$reddit_data_cols_ui <- renderUI({
                        actionButton("reset_reddit_dt_columns", "Reset")),
                    checkboxGroupInput("show_reddit_cols", label = NULL,
                                       choices = red_rv$data_cols,
-                                      selected = c("structure", "comm_date", "subreddit", "user", "comment_score", 
-                                                   "comment", "thread_id"),
+                                      selected = c("subreddit", "thread_id", "comm_id", "comm_date", "user", 
+                                                   "comment_score", "comment"),
                                       inline = TRUE, width = '98%')
   )
 })
 
-#### reactives -------------------------------------------------------------------------------------------------------- #
+#### reactives ------------------------------------------------------------------------------------------------------- #
 
 # add to the list of reddit thread urls to collect on
 urlListAdd <- reactive({
@@ -231,9 +199,7 @@ urlListAdd <- reactive({
   
   url <- createRedditRequestUrl(url)
   
-  if (is.null(url) || url == "") {
-    return(NULL)
-  }
+  if (is.null(url) || url == "") { return(NULL) }
   
   # only add if not already in list
   if (!(url %in% reddit_url_list)) {
@@ -257,23 +223,15 @@ urlListRemove <- reactive({
 datatableRedditData <- reactive({
   data <- red_rv$reddit_data
   
-  if (is.null(data)) {
-    return(NULL)
-  }
+  if (is.null(data)) { return(NULL) }
   
   if (!is.null(input$show_reddit_cols)) {
     if (length(input$show_reddit_cols) > 0) {
       data <- dplyr::select(red_rv$reddit_data, input$show_reddit_cols)
-    } else {
-      return(NULL)
-    }
-  } else {
-    return(NULL)
-  }
+    } else { return(NULL) }
+  } else { return(NULL) }
   
-  if (nrow(data) < 1) {
-    return(NULL)
-  }
+  if (nrow(data) < 1) { return(NULL) }
   
   col_classes <- sapply(data, class)
   for (i in seq(1, length(col_classes))) {
@@ -292,11 +250,12 @@ datatableRedditData <- reactive({
     DT::datatable(data, extensions = 'Buttons', filter = "top",
                   options = list(lengthMenu = gbl_dt_menu_len, pageLength = gbl_dt_page_len, scrollX = TRUE,
                                  columnDefs = col_defs, dom = 'lBfrtip',
-                                 buttons = c('copy', 'csv', 'excel', 'print')), class = 'cell-border stripe compact hover')
+                                 buttons = c('copy', 'csv', 'excel', 'print')),
+                  class = 'cell-border stripe compact hover')
   }
 })
 
-#### functions -------------------------------------------------------------------------------------------------------- #
+#### functions ------------------------------------------------------------------------------------------------------- #
 
 # format reddit collection arguments output
 redditArgumentsOutput <- function() {
@@ -306,7 +265,7 @@ redditArgumentsOutput <- function() {
   
   if (!is.null(reddit_url_list) && length(reddit_url_list) > 0) {
     thread_flag <- TRUE
-    output <- append(output, paste0("threads: ", trimws(paste0(reddit_url_list, collapse = ", "))))
+    output <- append(output, paste0("threads: ", trimws(paste0(reddit_url_list, collapse = ",\n"))))
   }
   
   # if thread urls have been inputed enable collect button
