@@ -3,7 +3,7 @@
 #' Collects tweets and creates an actor network using the vosonSML package.
 #'
 
-#### values ----------------------------------------------------------------------------------------------------------- #
+#### values ---------------------------------------------------------------------------------------------------------- #
 
 tw_rv <- reactiveValues(
   tw_data = NULL,        # dataframe returned by vosonSML collection
@@ -11,7 +11,7 @@ tw_rv <- reactiveValues(
   tw_graphml = NULL      # igraph graph object returned from collection
 )
 
-test_data <- NULL
+tw_data <- NULL
 
 tw_rv$data_cols <- NULL
 
@@ -45,10 +45,11 @@ twitter_filter_url <- NULL
 twitter_filter_negative <- NULL
 twitter_filter_positive <- NULL
 
-#### events ----------------------------------------------------------------------------------------------------------- #
+#### events ---------------------------------------------------------------------------------------------------------- #
 
 # set twitter parameters on input
-observeEvent({input$twitter_search_term_input
+observeEvent({
+  input$twitter_search_term_input
   input$twitter_retweets_check
   input$twitter_retry_check
   input$twitter_search_type_select
@@ -63,7 +64,6 @@ observeEvent({input$twitter_search_term_input
   input$twitter_filter_negative
   input$twitter_filter_positive              
 }, {
-  
   setTwitterParams()
 })
 
@@ -75,7 +75,6 @@ observeEvent(input$twitter_language_input, {
       updateTextInput(session, "twitter_language_input", value = "")
     }
   }
-  
   setTwitterParams()
 })
 
@@ -86,13 +85,11 @@ observeEvent(input$twitter_tweet_count_input, {
       updateNumericInput(session, "twitter_tweet_count_input", value = gbl_def_tweet_count)
     }
   }
-  
   setTwitterParams()
 })
 
 observeEvent(input$clear_twitter_console, {
   resetConsole("twitter_console")
-  # callModule(resetConsoleMod, "twitter")
 })
   
 # twitter collection button pushed
@@ -102,84 +99,65 @@ observeEvent(input$twitter_collect_button, {
   shinyjs::disable("twitter_collect_button")
   
   withProgress(message = 'Collecting tweets', value = 0.5, {
-    
-    # callModule(withConsoleRedirectMod, "twitter", value = {
     withConsoleRedirect("twitter_console", {
       
       # collect twitter data and print any output to console
       withCallingHandlers(
-      tryCatch({
-        search_term <- twitter_search_term
-        search_type <- twitter_search_type
-        
-        twitter_search_options <- c()
-        
-        if (nchar(twitter_filter_from) > 2) {
-          twitter_search_options <- append(twitter_search_options, paste0("from:", twitter_filter_from))
-        }
-        
-        if (nchar(twitter_filter_to) > 2) {
-          twitter_search_options <- append(twitter_search_options, paste0("to:", twitter_filter_to))
-        }
-        
-        # "-filter:nativeretweets" = !twitter_retweets,
-        opts <- list("filter:safe" = !twitter_filter_safe,
-                     "filter:media" = !twitter_filter_media,
-                     "filter:links" = !twitter_filter_url,
-                     ":)" = !twitter_filter_positive,
-                     ":(" = !twitter_filter_negative)
-        
-        sapply(names(opts), function(x) {
-          if (!VOSONDash::isNullOrEmpty(opts[x])) {
-            if (opts[x] == FALSE) { twitter_search_options <<- append(twitter_search_options, x) }
+        tryCatch({
+          search_term <- twitter_search_term
+          search_type <- twitter_search_type
+          
+          twitter_search_options <- c()
+          
+          if (nchar(twitter_filter_from) > 2) {
+            twitter_search_options <- append(twitter_search_options, paste0("from:", twitter_filter_from))
           }
-        })
-        
-        if (length(twitter_search_options) > 0) {
-          search_term <- ifelse(nchar(trimws(search_term)) > 0, paste0(search_term, " "), "")
-          search_term <- paste0(search_term, paste0(twitter_search_options, collapse = " "))
-        }
-        
-        # tw_api_keyring, search_term, search_type, tweet_count, 
-        # include_retweets, retry_on_rate_limit,
-        # language, date_until, since_id, max_id
-        test_data <<- suppressWarnings({
-          VOSONDash::collectTwitterData(cred = creds_rv$use_token, search_term, search_type,
-                                        twitter_tweet_count, twitter_retweets, twitter_retry, 
-                                        twitter_language, twitter_date_until,
-                                        twitter_since_id, twitter_max_id) })
-        
-        tw_rv$tw_data <<- test_data
-        
-        tw_rv$data_cols <<- names(tw_rv$tw_data)
-      }, error = function(err) {
-        incProgress(1, detail = "Error")
-        cat(paste("twitter collection error: ", err))
-        NULL
-      }, warning = function(w) {
-        incProgress(1, detail = "Warning")
-        cat(paste("twitter collection warning: ", w))
-        # invokeRestart("muffleWarning")
-      })
-      )
-      
-      if (!v029) {
-        # if twitter data collected create igraph graph object
-        if (!is.null(tw_rv$tw_data) && nrow(tw_rv$tw_data) > 0) {
-          incProgress(0.5, detail = "Creating network")
-          tryCatch({
-            # tw_rv$tw_graphml <<- createTwitterActorNetwork(tw_rv$tw_data)
-            netList <- VOSONDash::createTwitterActorNetwork(tw_rv$tw_data)
-            tw_rv$tw_graphml <<- netList$network
-            tw_rv$twitterWT_graphml <<- netList$networkWT   # "with text" (edge attribute)
-          }, error = function(err) {
-            incProgress(1, detail = "Error")
-            cat(paste("twitter graphml error: ", err))
+          
+          if (nchar(twitter_filter_to) > 2) {
+            twitter_search_options <- append(twitter_search_options, paste0("to:", twitter_filter_to))
+          }
+          
+          # "-filter:nativeretweets" = !twitter_retweets,
+          opts <- list("filter:safe" = !twitter_filter_safe,
+                       "filter:media" = !twitter_filter_media,
+                       "filter:links" = !twitter_filter_url,
+                       ":)" = !twitter_filter_positive,
+                       ":(" = !twitter_filter_negative)
+          
+          sapply(names(opts), function(x) {
+            if (!VOSONDash::isNullOrEmpty(opts[x])) {
+              if (opts[x] == FALSE) { twitter_search_options <<- append(twitter_search_options, x) }
+            }
           })
-        }
-      }
+          
+          if (length(twitter_search_options) > 0) {
+            search_term <- ifelse(nchar(trimws(search_term)) > 0, paste0(search_term, " "), "")
+            search_term <- paste0(search_term, paste0(twitter_search_options, collapse = " "))
+          }
+          
+          # tw_api_keyring, search_term, search_type, tweet_count, 
+          # include_retweets, retry_on_rate_limit, language, date_until, since_id, max_id
+          tw_data <- suppressWarnings({
+            VOSONDash::collectTwitterData(cred = creds_rv$use_token, search_term, search_type,
+                                          twitter_tweet_count, twitter_retweets, twitter_retry, 
+                                          twitter_language, twitter_date_until,
+                                          twitter_since_id, twitter_max_id) })
+          
+          tw_rv$tw_data <- tw_data
+          
+          tw_rv$data_cols <- names(tw_rv$tw_data)
+        }, error = function(err) {
+          incProgress(1, detail = "Error")
+          cat(paste("twitter collection error: ", err))
+          NULL
+        }, warning = function(w) {
+          incProgress(1, detail = "Warning")
+          cat(paste("twitter collection warning: ", w))
+        })
+      ) # withCallingHandlers
       
       incProgress(1, detail = "Finished")
+      updateTabItems(session, "twitter_control_tabset", selected = "Create Network")
       
     }) # withConsoleRedirect
     
@@ -217,50 +195,60 @@ observeEvent(input$twitter_create_button, {
   
   shinyjs::disable("twitter_create_button")
   
-  withProgress(message = 'Creating network', value = 0.5, {
+  withProgress(message = "Creating network", value = 0.5, {
   
-  withConsoleRedirect("twitter_console", {
-    if (net_type == "activity") {
-      network <- vosonSML::Create(isolate(tw_rv$tw_data), "activity", verbose = TRUE)
-      if (add_text) { network <- vosonSML::AddText(network, isolate(tw_rv$tw_data)) }
-    } else if (net_type == "actor") {
-      network <- vosonSML::Create(isolate(tw_rv$tw_data), "actor", verbose = TRUE)
-      if (add_text) { network <- vosonSML::AddText(network, isolate(tw_rv$tw_data)) }
-      if (add_user_data) { 
-        network <- vosonSML::AddUserData(network, isolate(tw_rv$tw_data), twitterAuth = creds_rv$use_token) 
+    withConsoleRedirect("twitter_console", {
+      if (net_type == "activity") {
+        network <- vosonSML::Create(isolate(tw_rv$tw_data), "activity", verbose = TRUE)
+        if (add_text) { network <- vosonSML::AddText(network, isolate(tw_rv$tw_data)) }
+      } else if (net_type == "actor") {
+        network <- vosonSML::Create(isolate(tw_rv$tw_data), "actor", verbose = TRUE)
+        if (add_text) { network <- vosonSML::AddText(network, isolate(tw_rv$tw_data)) }
+        if (add_user_data) { 
+          network <- vosonSML::AddUserData(network, isolate(tw_rv$tw_data), twitterAuth = creds_rv$use_token) 
+        }
+      } else if (net_type == "twomode") {
+        rem_terms <- parse_rem_terms(input$twitter_twomode_remove)
+        network <- NULL
+        tryCatch({
+          network <- vosonSML::Create(isolate(tw_rv$tw_data), "twomode",
+                                      removeTermsOrHashtags = rem_terms,
+                                      verbose = TRUE)
+        }, error = function(e) { cat(e$message) })
+      } else if (net_type == "semantic") {
+        rem_terms <- parse_rem_terms(input$twitter_semantic_remove)
+        network <- NULL
+        tryCatch({
+          if (is2910) {
+            network <- vosonSML::Create(isolate(tw_rv$tw_data), "semantic",
+                                        removeTermsOrHashtags = rem_terms,
+                                        stopwords = input$twitter_semantic_stopwords, # >= v0.29.10
+                                        termFreq = input$twitter_term_freq,
+                                        hashtagFreq = input$twitter_hashtag_freq,
+                                        assoc = ifelse(input$twitter_semantic_assoc, "limited", "full"), # >= v0.29.10
+                                        verbose = TRUE)
+          } else {
+            network <- vosonSML::Create(isolate(tw_rv$tw_data), "semantic",
+                                        removeTermsOrHashtags = rem_terms,
+                                        stopwordsEnglish = input$twitter_semantic_stopwords, # < v0.29.10
+                                        termFreq = input$twitter_term_freq,
+                                        hashtagFreq = input$twitter_hashtag_freq,
+                                        verbose = TRUE)            
+          }
+        }, error = function(e) { cat(e$message) })
+        
       }
-    } else if (net_type == "twomode") {
-      rem_terms <- parse_rem_terms(input$twitter_twomode_remove)
-      if (length(rem_terms)) {
-        network <- vosonSML::Create(isolate(tw_rv$tw_data), "twomode", removeTermsOrHashtags = rem_terms,
-                                    verbose = TRUE)
-      } else {
-        network <- vosonSML::Create(isolate(tw_rv$tw_data), "twomode", verbose = TRUE) 
+      if (!is.null(network)) {
+        tw_rv$tw_network <- network
+        tw_rv$tw_graphml <- vosonSML::Graph(network) 
       }
-    } else if (net_type == "semantic") {
-      rem_terms <- parse_rem_terms(input$twitter_semantic_remove)
-
-      network <- vosonSML::Create(isolate(tw_rv$tw_data), "semantic", 
-                                  removeTermsOrHashtags = rem_terms,
-                                  stopwordsEnglish = input$twitter_semantic_stopwords,
-                                  termFreq = input$twitter_term_freq,
-                                  hashtagFreq = input$twitter_hashtag_freq,
-                                  verbose = TRUE)
-    }
-    if (!is.null(network)) {
-      tw_rv$tw_network <- network
-      tw_rv$tw_graphml <- vosonSML::Graph(network) 
-    }
-  })
-  
-  incProgress(1, detail = "Finished")
+    })
+    
+    incProgress(1, detail = "Finished")
   })
   
   shinyjs::enable("twitter_create_button")
-  
-  # shinyjs::runjs("jQuery( function() { var pre = jQuery('#twitter_console');
-  #                                      pre.scrollTop( pre.prop('scrollHeight') ); }); ")
-  
+
   delay(gbl_scroll_delay, js$scroll_console("twitter_console"))
 })
 
@@ -269,18 +257,9 @@ callModule(collectDataButtons, "twitter", data = reactive({ tw_rv$tw_data }), fi
 
 callModule(collectNetworkButtons, "twitter", network = reactive({ tw_rv$tw_network }), file_prefix = "twitter")
 
-if (v029) {
-  callModule(collectGraphButtons_, "twitter", graph_data = reactive({ tw_rv$tw_graphml }), file_prefix = "twitter")
+callModule(collectGraphButtons_, "twitter", graph_data = reactive({ tw_rv$tw_graphml }), file_prefix = "twitter")
   
-  twitter_view_rvalues <- callModule(collectViewGraphButtons, "twitter", graph_data = reactive({ tw_rv$tw_graphml }))  
-} else {
-  callModule(collectGraphButtons, "twitter", graph_data = reactive({ tw_rv$tw_graphml }), 
-             graph_wt_data = reactive({ tw_rv$twitterWT_graphml }), file_prefix = "twitter")
-  
-  twitter_view_rvalues <- callModule(collectViewGraphButtons, "twitter", 
-                                     graph_data = reactive({ tw_rv$tw_graphml }), 
-                                     graph_wt_data = reactive({ tw_rv$twitterWT_graphml }))
-}
+twitter_view_rvalues <- callModule(collectViewGraphButtons, "twitter", graph_data = reactive({ tw_rv$tw_graphml }))
 
 observeEvent(twitter_view_rvalues$data, {
   setGraphView(data = isolate(twitter_view_rvalues$data), 
@@ -291,7 +270,7 @@ observeEvent(twitter_view_rvalues$data, {
   updateCheckboxInput(session, "expand_demo_data_check", value = FALSE)
 }, ignoreInit = TRUE)
 
-#### output ----------------------------------------------------------------------------------------------------------- #
+#### output ---------------------------------------------------------------------------------------------------------- #
 
 output$twitter_collect_token_output <- renderText({
   if (!is.null(creds_rv$use_token)) {
@@ -363,9 +342,7 @@ observeEvent(input$reset_twitter_dt_columns, {
 output$twitter_data_cols_ui <- renderUI({
   data <- tw_rv$data_cols
   
-  if (is.null(data)) {
-    return(NULL)
-  }
+  if (is.null(data)) { return(NULL) }
   
   conditionalPanel(condition = 'input.expand_show_twitter_cols',
     div(actionButton("select_all_twitter_dt_columns", "Select all"), 
@@ -379,7 +356,7 @@ output$twitter_data_cols_ui <- renderUI({
   )
 })
 
-#### reactives -------------------------------------------------------------------------------------------------------- #
+#### reactives ------------------------------------------------------------------------------------------------------- #
 
 setTwitterAPIKeys <- reactive({
   tw_api_keyring$twitter_app_name <<- input$twitter_app_name_input
@@ -420,24 +397,16 @@ setTwitterParams <- reactive({
 datatableTwitterData <- reactive({
   data <- tw_rv$tw_data
   
-  if (is.null(data)) {
-    return(NULL)
-  }
+  if (is.null(data)) { return(NULL) }
   
   if (!is.null(input$show_twitter_cols)) {
-    # data <- tw_rv$tw_data[, input$show_twitter_cols, drop = FALSE]
     if (length(input$show_twitter_cols) > 0) {
       data <- dplyr::select(tw_rv$tw_data, input$show_twitter_cols)
-    } else {
-      return(NULL)
-    }
-  } else {
-    return(NULL)
-  }
+    
+    } else { return(NULL) }
+  } else { return(NULL) }
   
-  if (nrow(data) < 1) {
-    return(NULL)
-  }
+  if (nrow(data) < 1) { return(NULL) }
   
   col_classes <- sapply(data, class)
   for (i in seq(1, length(col_classes))) {
@@ -456,15 +425,15 @@ datatableTwitterData <- reactive({
     DT::datatable(data, extensions = 'Buttons', filter = "top",
                   options = list(lengthMenu = gbl_dt_menu_len, pageLength = gbl_dt_page_len, scrollX = TRUE,
                                  columnDefs = col_defs, dom = 'lBfrtip',
-                                 buttons = c('copy', 'csv', 'excel', 'print')), class = 'cell-border stripe compact hover')
+                                 buttons = c('copy', 'csv', 'excel', 'print')),
+                  class = 'cell-border stripe compact hover')
   }
 })
 
-#### functions -------------------------------------------------------------------------------------------------------- #
+#### functions ------------------------------------------------------------------------------------------------------- #
 
 # format twitter collection arguments output
 twitterArgumentsOutput <- function() {
-  
   output <- c()
   check_keys <- sapply(tw_api_keyring, VOSONDash::isNullOrEmpty)
   
@@ -478,9 +447,7 @@ twitterArgumentsOutput <- function() {
   output <- append(output, paste0("include retweets: ", ifelse(twitter_retweets, "yes", "no")))
   output <- append(output, paste0("retry on rate limit: ", ifelse(twitter_retry, "yes", "no")))
   
-  # if (search_term_flag) {
   output <- append(output, paste0("results type: ", trimws(twitter_search_type)))
-  # }
   
   twitter_search_options <- c()
   
