@@ -3,7 +3,7 @@
 #' Collects Youtube video comments and creates an actor network using the vosonSML package.
 #'
 
-#### values ----------------------------------------------------------------------------------------------------------- #
+#### values ---------------------------------------------------------------------------------------------------------- #
 
 yt_rv <- reactiveValues(
   yt_data = NULL,
@@ -18,7 +18,7 @@ youtube_api_key <- NULL        # youtube api key
 youtube_video_id_list <- c()   # list of youtube video ids to collect on
 youtube_max_comments <- 200
 
-#### events ----------------------------------------------------------------------------------------------------------- #
+#### events ---------------------------------------------------------------------------------------------------------- #
 
 # update youtube api key when field input changes
 observeEvent(input$youtube_api_key_input, {
@@ -62,42 +62,22 @@ observeEvent(input$youtube_collect_button, {
   withProgress(message = 'Collecting comments', value = 0.5, {
     
     withConsoleRedirect("youtube_console", {
-      # withCallingHandlers({
-      # shinyjs::html(id = "youtube_console", html = "")
-      
       youtube_video_id_list <- sapply(youtube_video_id_list, 
                                       function(x) gsub("^v=", "", x, ignore.case = TRUE, perl = TRUE))
       
       # collect youtube data and print any output to console
       tryCatch({
-        yt_rv$yt_data <<- collectYoutubeData(youtube_api_key, youtube_video_id_list, 
-                                                            youtube_max_comments)
+        yt_rv$yt_data <- collectYoutubeData(youtube_api_key, youtube_video_id_list, youtube_max_comments)
         
-        yt_rv$data_cols <<- names(yt_rv$yt_data)
+        yt_rv$data_cols <- names(yt_rv$yt_data)
       }, error = function(err) {
         incProgress(1, detail = "Error")
         cat(paste('youtube collection error:', err))
         return(NULL)
       })
       
-      if (!v029) {
-        incProgress(0.5, detail = "Creating network")
-        
-        # if youtube data collected create igraph graph object
-        if (!is.null(yt_rv$yt_data)) {
-          tryCatch({
-            # yt_rv$yt_graphml <<- createYoutubeNetwork(yt_rv$yt_data)
-            netList <- createYoutubeNetwork(yt_rv$yt_data)
-            yt_rv$yt_graphml <<- netList$network
-            yt_rv$yt_wt_graphml <<- netList$networkWT   # "with text" (edge attribute)          
-          }, error = function(err) {
-            incProgress(1, detail = "Error")
-            cat(paste('youtube graphml error:', err))
-            return(NULL)
-          })
-        }
-      }
       incProgress(1, detail = "Finished")
+      updateTabItems(session, "youtube_control_tabset", selected = "Create Network")
       
     }) # withConsoleRedirect
     
@@ -126,30 +106,38 @@ observeEvent(input$youtube_create_button, {
   
   withProgress(message = 'Creating network', value = 0.5, {
     
-  withConsoleRedirect("youtube_console", {
-    if (net_type == "activity") {
-      network <- vosonSML::Create(isolate(yt_rv$yt_data), "activity", verbose = TRUE)
-      if (add_text) { network <- vosonSML::AddText(network, isolate(yt_rv$yt_data)) }
-    } else if (net_type == "actor") {
-      network <- vosonSML::Create(isolate(yt_rv$yt_data), "actor", verbose = TRUE)
-      if (add_text) {
-          network <- vosonSML::AddText(network, isolate(yt_rv$yt_data), 
-                                       replies_from_text = input$youtube_network_replies_from_text)
+    withConsoleRedirect("youtube_console", {
+      if (net_type == "activity") {
+        network <- vosonSML::Create(isolate(yt_rv$yt_data), "activity", verbose = TRUE)
+        if (add_text) { 
+          network <- vosonSML::AddText(network, isolate(yt_rv$yt_data))
+        }
+      } else if (net_type == "actor") {
+        network <- vosonSML::Create(isolate(yt_rv$yt_data), "actor", verbose = TRUE)
+        if (add_text) {
+            if (is2910) {
+              # vosonSML changed param name
+              network <- vosonSML::AddText(network, isolate(yt_rv$yt_data), 
+                                           repliesFromText = input$youtube_network_replies_from_text)
+            } else {
+              network <- vosonSML::AddText(network, isolate(yt_rv$yt_data), 
+                                           replies_from_text = input$youtube_network_replies_from_text) 
+            }
+        }
+        if (input$youtube_network_video_data) { 
+          creds <- vosonSML::Authenticate("youtube", apiKey = youtube_api_key)
+          network <- vosonSML::AddVideoData(network, youtubeAuth = creds,
+                                            actorSubOnly = input$youtube_network_video_subs)
+        }
       }
-      if (input$youtube_network_video_data) { 
-        creds <- vosonSML::Authenticate("youtube", apiKey = youtube_api_key)
-        network <- vosonSML::AddVideoData(network, youtubeAuth = creds,
-                                          actorSubOnly = input$youtube_network_video_subs)
+      if (!is.null(network)) { 
+        yt_rv$yt_network <- network
+        yt_rv$yt_graphml <- vosonSML::Graph(network)
       }
-    }
-    if (!is.null(network)) { 
-      yt_rv$yt_network <- network
-      yt_rv$yt_graphml <- vosonSML::Graph(network)
-    }
-  })
-    
-  incProgress(1, detail = "Finished")
-  })
+    }) # withConsoleRedirect
+      
+    incProgress(1, detail = "Finished")
+  }) # withProgress
   
   shinyjs::enable("youtube_create_button")
   
@@ -161,18 +149,9 @@ callModule(collectDataButtons, "youtube", data = reactive({ yt_rv$yt_data }), fi
 
 callModule(collectNetworkButtons, "youtube", network = reactive({ yt_rv$yt_network }), file_prefix = "youtube")
 
-if (v029) {
-  callModule(collectGraphButtons_, "youtube", graph_data = reactive({ yt_rv$yt_graphml }), file_prefix = "youtube")
-  
-  youtube_view_rvalues <- callModule(collectViewGraphButtons, "youtube", graph_data = reactive({ yt_rv$yt_graphml }))  
-} else {
-  callModule(collectGraphButtons, "youtube", graph_data = reactive({ yt_rv$yt_graphml }), 
-             graph_wt_data = reactive({ yt_rv$yt_wt_graphml }), file_prefix = "youtube")
-  
-  youtube_view_rvalues <- callModule(collectViewGraphButtons, "youtube", 
-                                     graph_data = reactive({ yt_rv$yt_graphml }), 
-                                     graph_wt_data = reactive({ yt_rv$yt_wt_graphml }))
-}
+callModule(collectGraphButtons_, "youtube", graph_data = reactive({ yt_rv$yt_graphml }), file_prefix = "youtube")
+
+youtube_view_rvalues <- callModule(collectViewGraphButtons, "youtube", graph_data = reactive({ yt_rv$yt_graphml }))  
 
 observeEvent(youtube_view_rvalues$data, {
   setGraphView(data = isolate(youtube_view_rvalues$data), 
@@ -188,7 +167,7 @@ observeEvent(input$clear_youtube_console, {
   resetConsole("youtube_console")
 })
 
-#### output ----------------------------------------------------------------------------------------------------------- #
+#### output ---------------------------------------------------------------------------------------------------------- #
 
 # render youtube collection arguments
 output$youtube_arguments_output <- renderText({
@@ -225,11 +204,7 @@ observeEvent(input$clear_all_youtube_dt_columns, {
 })
 
 dt_yt_cols <- function() {
-  if (v029) {
-    return(c("Comment", "AuthorDisplayName", "VideoID", "PublishedAt"))
-  } else {
-    return(c("Comment", "User", "PublishTime"))
-  }
+  return(c("Comment", "AuthorDisplayName", "VideoID", "PublishedAt"))
 }
 
 observeEvent(input$reset_youtube_dt_columns, {
@@ -242,9 +217,7 @@ observeEvent(input$reset_youtube_dt_columns, {
 output$youtube_data_cols_ui <- renderUI({
   data <- yt_rv$data_cols
   
-  if (is.null(data)) {
-    return(NULL)
-  }
+  if (is.null(data)) { return(NULL) }
   
   conditionalPanel(condition = 'input.expand_show_youtube_cols',
                    div(actionButton("select_all_youtube_dt_columns", "Select all"), 
@@ -253,11 +226,10 @@ output$youtube_data_cols_ui <- renderUI({
                    checkboxGroupInput("show_youtube_cols", label = NULL,
                                       choices = yt_rv$data_cols,
                                       selected = dt_yt_cols(),
-                                      inline = TRUE, width = '98%')
-  )
+                                      inline = TRUE, width = '98%'))
 })
 
-#### reactives -------------------------------------------------------------------------------------------------------- #
+#### reactives ------------------------------------------------------------------------------------------------------- #
 
 setYoutubeAPIKey <- reactive({
   youtube_api_key <<- trimws(input$youtube_api_key_input)
@@ -272,11 +244,8 @@ videoListAdd <- reactive({
   }
   
   video_id <- getYoutubeVideoId(input$youtube_video_id_input)
-  if (is.null(video_id)) {
-    return(NULL)
-  }
+  if (is.null(video_id)) { return(NULL) }
   
-  # video_id <- paste0("id:", video_id)
   # only add if not already in list
   if (!(trimws(video_id) %in% youtube_video_id_list)) {
     youtube_video_id_list <<- append(youtube_video_id_list, trimws(video_id))
@@ -299,23 +268,15 @@ videoListRemove <- reactive({
 datatableYoutubeData <- reactive({
   data <- yt_rv$yt_data
   
-  if (is.null(data)) {
-    return(NULL)
-  }
+  if (is.null(data)) { return(NULL) }
   
   if (!is.null(input$show_youtube_cols)) {
     if (length(input$show_youtube_cols) > 0) {
       data <- dplyr::select(yt_rv$yt_data, input$show_youtube_cols)
-    } else {
-      return(NULL)
-    }
-  } else {
-    return(NULL)
-  }
+    } else { return(NULL) }
+  } else { return(NULL) }
   
-  if (nrow(data) < 1) {
-    return(NULL)
-  }
+  if (nrow(data) < 1) { return(NULL) }
 
   col_classes <- sapply(data, class)
   for (i in seq(1, length(col_classes))) {
@@ -334,11 +295,12 @@ datatableYoutubeData <- reactive({
     DT::datatable(data, extensions = 'Buttons', filter = "top",
                   options = list(lengthMenu = gbl_dt_menu_len, pageLength = gbl_dt_page_len, scrollX = TRUE,
                                  columnDefs = col_defs, dom = 'lBfrtip',
-                                 buttons = c('copy', 'csv', 'excel', 'print')), class = 'cell-border stripe compact hover')
+                                 buttons = c('copy', 'csv', 'excel', 'print')),
+                  class = 'cell-border stripe compact hover')
   }
 })
 
-#### functions -------------------------------------------------------------------------------------------------------- #
+#### functions ------------------------------------------------------------------------------------------------------- #
 
 # format youtube collection arguments output
 youtubeArgumentsOutput <- function() {
@@ -368,4 +330,3 @@ youtubeArgumentsOutput <- function() {
   
   paste0(output, collapse = '\n')
 }
-
